@@ -77,11 +77,4 @@ def mi_endpoint_list() -> List[Endpoint]:
         for section
         in config.sections()
         if section.startswith('endpoint')
-    ]
-
-
-def mi_endpoint_change_pwd(name: str, pwd: str) -> Endpoint:
-    endpoints = mi_endpoint_list()
-    keyring.set_password(SERVICE_ID, name, pwd)
-
-    return mi_endpoint_get(name)
+    ]
\ No newline at end of file
